@@ -107,7 +107,7 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         headers = kwargs.pop("headers", {})
         self.keep_alive and headers.update(Connection = "keep-alive")
 
-        super(TornadoHTTPClient, self).fetch(request, callback, **kwargs)
+        super(TornadoHTTPClient, self).fetch(request, callback, headers = headers, **kwargs)
 
 
     def _fetch(self, request, callback, kwargs, delay):
